==> zio-aws-waf_2.13-5.17.104.1-sources.jar: zio/aws/waf/model/GetRegexPatternSetResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetRegexPatternSetResponse(
    regexPatternSet: Option[zio.aws.waf.model.RegexPatternSet] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.GetRegexPatternSetResponse = {
    import GetRegexPatternSetResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.GetRegexPatternSetResponse
      .builder()
      .optionallyWith(regexPatternSet.map(value => value.buildAwsValue()))(
        _.regexPatternSet
      )
      .build()
  }
  def asReadOnly: zio.aws.waf.model.GetRegexPatternSetResponse.ReadOnly =
    zio.aws.waf.model.GetRegexPatternSetResponse.wrap(buildAwsValue())
}
object GetRegexPatternSetResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.GetRegexPatternSetResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.GetRegexPatternSetResponse =
      zio.aws.waf.model.GetRegexPatternSetResponse(
        regexPatternSet.map(value => value.asEditable)
      )
    def regexPatternSet: Option[zio.aws.waf.model.RegexPatternSet.ReadOnly]
    def getRegexPatternSet
        : ZIO[Any, AwsError, zio.aws.waf.model.RegexPatternSet.ReadOnly] =
      AwsError.unwrapOptionField("regexPatternSet", regexPatternSet)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.GetRegexPatternSetResponse
  ) extends zio.aws.waf.model.GetRegexPatternSetResponse.ReadOnly {
    override val regexPatternSet
        : Option[zio.aws.waf.model.RegexPatternSet.ReadOnly] = scala
      .Option(impl.regexPatternSet())
      .map(value => zio.aws.waf.model.RegexPatternSet.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.GetRegexPatternSetResponse
  ): zio.aws.waf.model.GetRegexPatternSetResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-waf_2.13-5.19.8.4-sources.jar: zio/aws/waf/model/GetRegexPatternSetResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetRegexPatternSetResponse(
    regexPatternSet: Optional[zio.aws.waf.model.RegexPatternSet] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.GetRegexPatternSetResponse = {
    import GetRegexPatternSetResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.GetRegexPatternSetResponse
      .builder()
      .optionallyWith(regexPatternSet.map(value => value.buildAwsValue()))(
        _.regexPatternSet
      )
      .build()
  }
  def asReadOnly: zio.aws.waf.model.GetRegexPatternSetResponse.ReadOnly =
    zio.aws.waf.model.GetRegexPatternSetResponse.wrap(buildAwsValue())
}
object GetRegexPatternSetResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.GetRegexPatternSetResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.GetRegexPatternSetResponse =
      zio.aws.waf.model.GetRegexPatternSetResponse(
        regexPatternSet.map(value => value.asEditable)
      )
    def regexPatternSet: Optional[zio.aws.waf.model.RegexPatternSet.ReadOnly]
    def getRegexPatternSet
        : ZIO[Any, AwsError, zio.aws.waf.model.RegexPatternSet.ReadOnly] =
      AwsError.unwrapOptionField("regexPatternSet", regexPatternSet)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.GetRegexPatternSetResponse
  ) extends zio.aws.waf.model.GetRegexPatternSetResponse.ReadOnly {
    override val regexPatternSet
        : Optional[zio.aws.waf.model.RegexPatternSet.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.regexPatternSet())
        .map(value => zio.aws.waf.model.RegexPatternSet.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.GetRegexPatternSetResponse
  ): zio.aws.waf.model.GetRegexPatternSetResponse.ReadOnly = new Wrapper(impl)
}
